This function extracts the cluster variable from a table by applying a schema description to it.
getClusterVar(schema = NULL, input = NULL)a list per cluster with values of the cluster variable
input <- tabs2shift$clusters_nested
schema <- setCluster(id = "sublevel",
group = "territories", member = c(1, 1, 2),
left = 1, top = c(3, 8, 15)) %>%
setIDVar(name = "territories", columns = 1, rows = c(2, 14)) %>%
setIDVar(name = "sublevel", columns = 1, rows = c(3, 8, 15)) %>%
setIDVar(name = "year", columns = 7) %>%
setIDVar(name = "commodities", columns = 2) %>%
setObsVar(name = "harvested", columns = 5) %>%
setObsVar(name = "production", columns = 6)
validateSchema(schema = schema, input = input) %>%
getClusterVar(input = input)
#> Warning: validateSchema(): 'rows' is set for variable 'territories', but 'columns' has only one entry (column 1). 'rows' is only meaningful when the variable spans multiple columns (wide format). If you want a distinct variable, set distinct = TRUE and provide explicit rows.
#> Warning: validateSchema(): variable 'territories' has rows = c(2, 14) (length 2) but there are 3 cluster origins. The number of row values should match the number of cluster origins.
#> $sublevel
#> # A tibble: 1 × 1
#> X1
#> <chr>
#> 1 unit 1
#>
#> $sublevel
#> # A tibble: 1 × 1
#> X1
#> <chr>
#> 1 unit 2
#>
#> $sublevel
#> # A tibble: 1 × 1
#> X1
#> <chr>
#> 1 unit 3
#>