This function extracts the observed variables from a table by applying a schema description to it.
getObsVars(schema = NULL, input = NULL)a list per cluster with values of the observed variables
input <- tabs2shift$clusters_nested
schema <- setCluster(id = "sublevel",
group = "territories", member = c(1, 1, 2),
left = 1, top = c(3, 8, 15)) %>%
setIDVar(name = "territories", columns = 1, rows = c(2, 14)) %>%
setIDVar(name = "sublevel", columns = 1, rows = c(3, 8, 15)) %>%
setIDVar(name = "year", columns = 7) %>%
setIDVar(name = "commodities", columns = 2) %>%
setObsVar(name = "harvested", columns = 5) %>%
setObsVar(name = "production", columns = 6)
validateSchema(schema = schema, input = input) %>%
getObsVars(input = input)
#> Warning: validateSchema(): 'rows' is set for variable 'territories', but 'columns' has only one entry (column 1). 'rows' is only meaningful when the variable spans multiple columns (wide format). If you want a distinct variable, set distinct = TRUE and provide explicit rows.
#> Warning: validateSchema(): variable 'territories' has rows = c(2, 14) (length 2) but there are 3 cluster origins. The number of row values should match the number of cluster origins.
#> [[1]]
#> [[1]]$harvested
#> # A tibble: 4 × 1
#> X5
#> <chr>
#> 1 1111
#> 2 1121
#> 3 1211
#> 4 1221
#>
#> [[1]]$production
#> # A tibble: 4 × 1
#> X6
#> <chr>
#> 1 1112
#> 2 1122
#> 3 1212
#> 4 1222
#>
#>
#> [[2]]
#> [[2]]$harvested
#> # A tibble: 4 × 1
#> X5
#> <chr>
#> 1 2111
#> 2 2121
#> 3 2211
#> 4 2221
#>
#> [[2]]$production
#> # A tibble: 4 × 1
#> X6
#> <chr>
#> 1 2112
#> 2 2122
#> 3 2212
#> 4 2222
#>
#>
#> [[3]]
#> [[3]]$harvested
#> # A tibble: 4 × 1
#> X5
#> <chr>
#> 1 3111
#> 2 3121
#> 3 3211
#> 4 3221
#>
#> [[3]]$production
#> # A tibble: 4 × 1
#> X6
#> <chr>
#> 1 3112
#> 2 3122
#> 3 3212
#> 4 3222
#>
#>